// This file has been copied 1:1 from www.spale.com/download/scrypt/scrypt1.0/sha256.c
// Besides these 2 comment lines and the correction of uint32 (see below) nothing has been changed.

#ifndef _SHA256_H
#define _SHA256_H

#ifndef uint8
#define uint8  unsigned char
#endif

#ifndef uint32
#define uint32 unsigned int // Hier stand "long int", was für amd64 an sich falsch ist (siehe auch Bemerkung zu SHR in sha256.cpp)
#endif

typedef struct
{
    uint32 total[2];
    uint32 state[8];
    uint8 buffer[64];
} sha256_context;

void sha256_starts( sha256_context *ctx );
void sha256_update( sha256_context *ctx, uint8 *input, uint32 length );
void sha256_finish( sha256_context *ctx, uint8 digest[32] );

#endif /* sha256.h */

